#!/usr/bin/python

import numpy as np
import scipy as sp
from scipy import special
import math
import matplotlib.pyplot as plt
import matplotlib
from mpl_toolkits.mplot3d import Axes3D
matplotlib.rcParams['figure.figsize'] = 30,30
matplotlib.rcParams.update({'font.size': 20})

import scipy.integrate as integrate
import scipy.special as special


# Contact pressure is distributed from 0 to L 
E = 2.1e11
v = 0.3
a = .01    # 1 cm
p0 = 1.e6  # 1 MPa
#R0 = ??? # Indenter's radius

# Pressure distribution
def Pres(x):
  if x >= -a and x <= a:
  	#return p0*np.sqrt(1-(x/a)**2) # Hertz
  	#return p0/np.sqrt(1-(x/a)**2)
  	return p0
  else: 
  	return 0.
pres = np.vectorize(Pres)

# Integrands
def fxx(x,y,s):
  return -2*y*(x-s)**2*pres(s)/(np.pi*((x-s)**2 + y**2)**2)
def fyy(x,y,s):
  return -2*y**3*pres(s)/(np.pi*((x-s)**2 + y**2)**2) 
def fxy(x,y,s):
  return -2*y**2*(x-s)*pres(s)/(np.pi*((x-s)**2 + y**2)**2) 
def disp(x,s):
  return 2*(1-v**2)/(np.pi*E)*pres(s)*np.log(abs(x-s))

N=300
x0 = -4.*a
x1 =  4.*a
dx =  (x1-x0)/float(N) 
uy        = np.zeros(N)
xx = np.linspace(x0,x1,num=N)
error = np.zeros(N)

for i in range(N):
  x = x0 + dx*i
  uy[i],error[i] = integrate.quad(lambda s:disp(x,s),x0,x1,points=(-a,a),epsabs=1e-10) 
  #uy[i] = integrate.fixed_quad(lambda s:disp(x,s),x0,x1,n=10000)[0] 
  #uy[i] = integrate.trapz(lambda s:disp(x,s),x0,x1)[0] 

#print error 

#print uy

fig,ax = plt.subplots()
plt.grid("on")
plt.xlabel("Coordinate, x/a")
plt.xlabel("Vertical displacement, uy")
#plt.ylim([-1e-7,3e-7])
#print np.nanmin(uy)
plt.plot(xx/a,uy,"-")
#R=1.2e3
#plt.plot(xx/a,xx**2/(2*R),"-")
plt.show()
fig.savefig("Displacement.png")
