#!/usr/bin/python

import numpy as np
import scipy as sp
from scipy import special
import math
import matplotlib.pyplot as plt
import matplotlib
from mpl_toolkits.mplot3d import Axes3D
matplotlib.rcParams['figure.figsize'] = 30,30
matplotlib.rcParams.update({'font.size': 20})

import scipy.integrate as integrate
import scipy.special as special


# Contact pressure is distributed from 0 to L 
E = 2.1e11
v = 0.3
a = .01    # 1 cm
p0 = 1.e6  # 1 MPa

# Pressure distribution
def pres(x):
  if x >= -a and x <= a:
  	return p0*np.sqrt(1-(x/a)**2) # Hertz
  	#return p0/np.sqrt(1-(x/a)**2)
  	#return p0
  else: 
  	return 0.

# Integrands
def fxx(x,y,s):
  return -2*y*(x-s)**2*pres(s)/(np.pi*((x-s)**2 + y**2)**2)
def fyy(x,y,s):
  return -2*y**3*pres(s)/(np.pi*((x-s)**2 + y**2)**2) 
def fxy(x,y,s):
  return -2*y**2*(x-s)*pres(s)/(np.pi*((x-s)**2 + y**2)**2) 

N=25
x0 = -2*a
x1 =  2*a
dx =  (x1-x0)/float(N) 
dy =  (x1-x0)/float(N)

sig_xx    = np.zeros((N,N))
sig_yy    = np.zeros((N,N))
sig_xy    = np.zeros((N,N))
sig_zz    = np.zeros((N,N))
sig_mises = np.zeros((N,N))

for i in range(N):
  x = x0 + dx*i
  for j in range(1,N):
    y = dy*j
    sig_xx[i][j] = integrate.quad(lambda s:fxx(x,y,s),-a,a,points=(-a,a))[0] 
    sig_yy[i][j] = integrate.quad(lambda s:fyy(x,y,s),-a,a,points=(-a,a))[0]
    sig_xy[i][j] = integrate.quad(lambda s:fxy(x,y,s),-a,a,points=(-a,a))[0] 
    sig_zz[i][j] = v*(sig_xx[i][j] + sig_yy[i][j]) 
    sig_mises[i][j] = (0.5*((sig_xx[i,j] - sig_yy[i,j])**2 + (sig_yy[i,j]-sig_zz[i,j])**2 + (sig_xx[i,j]-sig_zz[i,j])**2 + 6*sig_xy[i,j]**2))**0.5

sig_max = np.max(sig_mises)
fig,ax = plt.subplots()
ax.grid(False)
my_cmap = matplotlib.cm.get_cmap('gnuplot')
plt.imshow(sig_mises.transpose(),vmin=0,vmax=sig_max, cmap=my_cmap,interpolation="bicubic")
plt.show()
fig.savefig("Mises_stress.png")

# HERE
sig_max = np.max(sig_mises)
wh = np.where(sig_mises == sig_max)
imax,jmax = int(wh[0]),int(wh[1])
print("Max von Mises stress normalized by p0 is = "+str(sig_max/p0))
print("It is located at (x/a,y/a) = ({0},{1})".format((x0 + imax*dx)/a,(jmax*dy)/a))




